@@ -26,6 +26,8 @@ has '_is_first_line' => (isa => "Bool", is => 'rw');
 has '_input' => (is => 'rw', init_arg => 'input', required => 1,);
 has '_output' => (is => 'rw', init_arg => 'output', required => 1,);
 has '_this_line' => (isa => 'Str', is => 'rw', default => '', );
+has '_buf' => (isa => 'ScalarRef[Str]', is => 'rw',
+    default => sub { my $s = ''; return \$s; });
 
 =head1 NAME
 
@@ -33,11 +35,11 @@ XML::Grammar::Fortune::ToText - convert the FortunesXML grammar to plaintext.
 
 =head1 VERSION
 
-Version 0.0508
+Version 0.0509
 
 =cut
 
-our $VERSION = '0.0508';
+our $VERSION = '0.0509';
 
 
 =head1 SYNOPSIS
@@ -69,7 +71,7 @@ sub _out
 {
     my $self = shift;
 
-    print {$self->_output()} @_;
+    ${$self->_buf()} .= join('', @_);
 
     return;
 }
@@ -160,6 +162,12 @@ sub run
         }
     );
 
+    my $buf = ${$self->_buf()};
+
+    $buf =~ s/[ \t]+$//gms;
+
+    print { $self->_output() } $buf;
+
     return;
 }
 
@@ -511,8 +519,8 @@ sub _get_formatted_node_text
 
     # Intent: format the text.
     # Trim leading and trailing nelines.
-    $text =~ s{\A\n+}{}ms;
-    $text =~ s{\n+\z}{}ms;
+    # $text =~ s{\A\n+}{}ms;
+    # $text =~ s{\n+\z}{}ms;
 
     # Convert a sequence of spaces to a single space.
     $text =~ s{\s+}{ }gms;
@@ -524,6 +532,8 @@ sub _render_para
 {
     my ($self, $para) = @_;
 
+    my $first_text = 1;
+
     foreach my $node ($para->childNodes())
     {
         if ($node->nodeType() == XML_ELEMENT_NODE())
@@ -549,11 +559,20 @@ sub _render_para
         }
         elsif ($node->nodeType() == XML_TEXT_NODE())
         {
-            $self->_append_to_this_line(
-                $self->_get_formatted_node_text($node)
-            );
+            my $text = $self->_get_formatted_node_text($node);
+
+            if ($first_text)
+            {
+                $text =~ s/\A\s+//;
+            }
+
+            $self->_append_to_this_line( $text );
         }
     }
+    continue
+    {
+        $first_text = 0;
+    }
 }
 
 sub _render_quote_list
